pub struct Zeroizing<Z>(/* private fields */)
where
Z: Zeroize + ?Sized;Expand description
Zeroizing owner used for decrypted plaintext and derived CEK bytes.
Zeroizing is a wrapper for any Z: Zeroize type which implements a
Drop handler which zeroizes dropped values.
Zeroizing<T> is defined with repr(transparent), which means it is
guaranteed to have the same physical representation as the underlying type.
Implementations